# skiplink

Les liens d’évitement permettent aux utilisateurs naviguant au clavier, ou équipés de lecteurs d'écran, d’accéder plus rapidement à des zones précises de la page.

## Dépendances
```shell
skiplink
└─ core
└─ link
```

## Utilisation
Afin d’utiliser le composant `skiplink`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
    <link href="css/link/link.min.css" rel="stylesheet">
    <link href="css/skiplink/skiplink.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/composants/lien-d-evitement) sur le module Liens d'évitement